==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceProviderCapabilitiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceProviderCapabilitiesArgs.builder
import com.pulumi.azurenative.providerhub.kotlin.enums.ResourceProviderCapabilitiesEffect
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property effect
 * @property quotaId
 * @property requiredFeatures
 */
public data class ResourceProviderCapabilitiesArgs(
    public val effect: Output<Either<String, ResourceProviderCapabilitiesEffect>>,
    public val quotaId: Output<String>,
    public val requiredFeatures: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceProviderCapabilitiesArgs> {
    override fun toJava(): com.pulumi.azurenative.providerhub.inputs.ResourceProviderCapabilitiesArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceProviderCapabilitiesArgs.builder()
            .effect(
                effect.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .quotaId(quotaId.applyValue({ args0 -> args0 }))
            .requiredFeatures(requiredFeatures?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ResourceProviderCapabilitiesArgs].
 */
@PulumiTagMarker
public class ResourceProviderCapabilitiesArgsBuilder internal constructor() {
    private var effect: Output<Either<String, ResourceProviderCapabilitiesEffect>>? = null

    private var quotaId: Output<String>? = null

    private var requiredFeatures: Output<List<String>>? = null

    /**
     * @param value
     */
    @JvmName("rearoftlkwcxlvwg")
    public suspend fun effect(`value`: Output<Either<String, ResourceProviderCapabilitiesEffect>>) {
        this.effect = value
    }

    /**
     * @param value
     */
    @JvmName("ngfvyhbptjucedxi")
    public suspend fun quotaId(`value`: Output<String>) {
        this.quotaId = value
    }

    /**
     * @param value
     */
    @JvmName("rlgforfocyecwvpy")
    public suspend fun requiredFeatures(`value`: Output<List<String>>) {
        this.requiredFeatures = value
    }

    @JvmName("wanambcdutkfgtxi")
    public suspend fun requiredFeatures(vararg values: Output<String>) {
        this.requiredFeatures = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("ltuxobdajvatidtc")
    public suspend fun requiredFeatures(values: List<Output<String>>) {
        this.requiredFeatures = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("jrluinbbcfyhfwyb")
    public suspend fun effect(`value`: Either<String, ResourceProviderCapabilitiesEffect>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.effect = mapped
    }

    /**
     * @param value
     */
    @JvmName("negistvlkmsjtjgk")
    public fun effect(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ResourceProviderCapabilitiesEffect>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.effect = mapped
    }

    /**
     * @param value
     */
    @JvmName("qufdqxiycuqslmyc")
    public fun effect(`value`: ResourceProviderCapabilitiesEffect) {
        val toBeMapped = Either.ofRight<String, ResourceProviderCapabilitiesEffect>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.effect = mapped
    }

    /**
     * @param value
     */
    @JvmName("auqcjhgpkqhqgadu")
    public suspend fun quotaId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.quotaId = mapped
    }

    /**
     * @param value
     */
    @JvmName("xhyrpqunbgufmgwh")
    public suspend fun requiredFeatures(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requiredFeatures = mapped
    }

    /**
     * @param values
     */
    @JvmName("gahtofqiqtykvymy")
    public suspend fun requiredFeatures(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.requiredFeatures = mapped
    }

    internal fun build(): ResourceProviderCapabilitiesArgs = ResourceProviderCapabilitiesArgs(
        effect = effect ?: throw PulumiNullFieldException("effect"),
        quotaId = quotaId ?: throw PulumiNullFieldException("quotaId"),
        requiredFeatures = requiredFeatures,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceProviderCapabilitiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceProviderCapabilitiesArgs.builder
import com.pulumi.azurenative.providerhub.kotlin.enums.ResourceProviderCapabilitiesEffect
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property effect
 * @property quotaId
 * @property requiredFeatures
 */
public data class ResourceProviderCapabilitiesArgs(
    public val effect: Output<Either<String, ResourceProviderCapabilitiesEffect>>,
    public val quotaId: Output<String>,
    public val requiredFeatures: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceProviderCapabilitiesArgs> {
    override fun toJava(): com.pulumi.azurenative.providerhub.inputs.ResourceProviderCapabilitiesArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceProviderCapabilitiesArgs.builder()
            .effect(
                effect.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .quotaId(quotaId.applyValue({ args0 -> args0 }))
            .requiredFeatures(requiredFeatures?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ResourceProviderCapabilitiesArgs].
 */
@PulumiTagMarker
public class ResourceProviderCapabilitiesArgsBuilder internal constructor() {
    private var effect: Output<Either<String, ResourceProviderCapabilitiesEffect>>? = null

    private var quotaId: Output<String>? = null

    private var requiredFeatures: Output<List<String>>? = null

    /**
     * @param value
     */
    @JvmName("mtntgbffkxppsxpu")
    public suspend fun effect(`value`: Output<Either<String, ResourceProviderCapabilitiesEffect>>) {
        this.effect = value
    }

    /**
     * @param value
     */
    @JvmName("nwiiidgtdwhethmx")
    public suspend fun quotaId(`value`: Output<String>) {
        this.quotaId = value
    }

    /**
     * @param value
     */
    @JvmName("qvbfrwjjnncodsla")
    public suspend fun requiredFeatures(`value`: Output<List<String>>) {
        this.requiredFeatures = value
    }

    @JvmName("gtepjenxtchbkkvt")
    public suspend fun requiredFeatures(vararg values: Output<String>) {
        this.requiredFeatures = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("wcdkebhyrlrrppoh")
    public suspend fun requiredFeatures(values: List<Output<String>>) {
        this.requiredFeatures = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("ldnaibnmfpimcdov")
    public suspend fun effect(`value`: Either<String, ResourceProviderCapabilitiesEffect>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.effect = mapped
    }

    /**
     * @param value
     */
    @JvmName("bpxpbhcaswiyjkxh")
    public fun effect(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ResourceProviderCapabilitiesEffect>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.effect = mapped
    }

    /**
     * @param value
     */
    @JvmName("ujxnsdrlbtdcfqft")
    public fun effect(`value`: ResourceProviderCapabilitiesEffect) {
        val toBeMapped = Either.ofRight<String, ResourceProviderCapabilitiesEffect>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.effect = mapped
    }

    /**
     * @param value
     */
    @JvmName("axonavjadoklkxno")
    public suspend fun quotaId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.quotaId = mapped
    }

    /**
     * @param value
     */
    @JvmName("rmaufmuilwjvjvld")
    public suspend fun requiredFeatures(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requiredFeatures = mapped
    }

    /**
     * @param values
     */
    @JvmName("qxgqdmrfnkybbloh")
    public suspend fun requiredFeatures(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.requiredFeatures = mapped
    }

    internal fun build(): ResourceProviderCapabilitiesArgs = ResourceProviderCapabilitiesArgs(
        effect = effect ?: throw PulumiNullFieldException("effect"),
        quotaId = quotaId ?: throw PulumiNullFieldException("quotaId"),
        requiredFeatures = requiredFeatures,
    )
}
